Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(125)

Unified Diff: chrome/browser/ui/intents/web_intent_picker_delegate.h

Issue 9148032: [Web Intents] Refactor picker to use WebIntentPickerModel. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: groby's fix Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/intents/web_intent_picker_delegate.h
diff --git a/chrome/browser/ui/intents/web_intent_picker_delegate.h b/chrome/browser/ui/intents/web_intent_picker_delegate.h
index 9f2c876db37bdfa4de18cb4d81a295cea2704e08..b2098c1da0ab5eefcfc8c473f55dad5b067fe776 100644
--- a/chrome/browser/ui/intents/web_intent_picker_delegate.h
+++ b/chrome/browser/ui/intents/web_intent_picker_delegate.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -6,21 +6,34 @@
#define CHROME_BROWSER_UI_INTENTS_WEB_INTENT_PICKER_DELEGATE_H_
#pragma once
+#include "chrome/browser/ui/intents/web_intent_picker_model.h"
+
+namespace content {
+class WebContents;
+}
+
// A class used to notify the delegate when the user has chosen a web intent
// service.
class WebIntentPickerDelegate {
public:
+ typedef WebIntentPickerModel::Disposition Disposition;
+
// Base destructor.
virtual ~WebIntentPickerDelegate() {}
- // Callback called when the user has chosen a service.
- virtual void OnServiceChosen(size_t index) = 0;
+ // Called when the user has chosen a service.
+ virtual void OnServiceChosen(size_t index, Disposition disposition) = 0;
+
+ // Called when the picker has created WebContents to use for inline
+ // disposition.
+ virtual void OnInlineDispositionWebContentsCreated(
+ content::WebContents* web_contents) = 0;
- // Callback called when the user cancels out of the dialog, whether by closing
- // it manually or otherwise purposefully.
+ // Called when the user cancels out of the dialog, whether by closing it
+ // manually or otherwise purposefully.
virtual void OnCancelled() = 0;
- // Callback called when the dialog stops showing.
+ // Called when the dialog stops showing.
virtual void OnClosing() = 0;
};

Powered by Google App Engine
This is Rietveld 408576698